mlbench_core.dataset
--------------------

.. autoapimodule:: mlbench_core.dataset
.. currentmodule:: mlbench_core.dataset


linearmodels
~~~~~~~~~~~~
.. autoapimodule:: mlbench_core.dataset.linearmodels
.. currentmodule:: mlbench_core.dataset.linearmodels

pytorch
+++++++

.. autoapimodule:: mlbench_core.dataset.linearmodels.pytorch.dataloader
.. currentmodule:: mlbench_core.dataset.linearmodels.pytorch.dataloader

Epsilon Logistic Regression
'''''''''''''''''''''''''''

.. autoapiclass:: LMDBDataset
    :members:

.. autoapiclass:: LMDBPTClass
    :members:

imagerecognition
~~~~~~~~~~~~~~~~

.. autoapimodule:: mlbench_core.dataset.imagerecognition
.. currentmodule:: mlbench_core.dataset.imagerecognition

pytorch
+++++++

.. autoapimodule:: mlbench_core.dataset.imagerecognition.pytorch.dataloader
.. currentmodule:: mlbench_core.dataset.imagerecognition.pytorch.dataloader

CIFAR10V1
'''''''''

.. autoapiclass:: CIFAR10V1
    :members:

Imagenet
''''''''

.. autoapiclass:: Imagenet
    :members:

tensorflow
++++++++++

.. autoapimodule:: mlbench_core.dataset.imagerecognition.tensorflow
.. currentmodule:: mlbench_core.dataset.imagerecognition.tensorflow

DatasetCifar
''''''''''''

.. autoapiclass:: DatasetCifar
    :members:
